==> igniteui-react-charts-16.6.8.tgz: package/ES5/TRIXIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TRIXIndicatorStrategy } from "./TRIXIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
import { Brush } from "igniteui-react-core/ES5/Brush";
/**
 * @hidden
 */
var TRIXIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(TRIXIndicator, _super);
    function TRIXIndicator() {
        var _this = _super.call(this) || this;
        _this.pd = 0;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 9;
        _this.trendLinePeriod = 9;
        return _this;
    }
    TRIXIndicator.prototype.get_p5 = function () {
        return new TRIXIndicatorStrategy();
    };
    Object.defineProperty(TRIXIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    TRIXIndicator.prototype.get_qi = function () {
        return TRIXIndicator.$;
    };
    Object.defineProperty(TRIXIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TRIXIndicator.prototype, "qq", {
        get: function () {
            return typeGetValue(this.c(TRIXIndicator.qr));
        },
        set: function (a) {
            this.h(TRIXIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    TRIXIndicator.prototype.qb = function () {
        return this.qq;
    };
    TRIXIndicator.prototype.qk = function (a) {
        this.qq = a;
    };
    TRIXIndicator.$t = markType(TRIXIndicator, 'TRIXIndicator', StrategyBasedIndicator.$);
    TRIXIndicator.qr = StrategyBasedIndicator.qn(15, TRIXIndicator.$);
    return TRIXIndicator;
}(StrategyBasedIndicator));
export { TRIXIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/TRIXIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TRIXIndicatorStrategy } from "./TRIXIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
import { Brush } from "igniteui-react-core/ES5/Brush";
/**
 * @hidden
 */
var TRIXIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(TRIXIndicator, _super);
    function TRIXIndicator() {
        var _this = _super.call(this) || this;
        _this.pk = 0;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 9;
        _this.trendLinePeriod = 9;
        return _this;
    }
    TRIXIndicator.prototype.get_qc = function () {
        return new TRIXIndicatorStrategy();
    };
    Object.defineProperty(TRIXIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    TRIXIndicator.prototype.get_qp = function () {
        return TRIXIndicator.$;
    };
    Object.defineProperty(TRIXIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TRIXIndicator.prototype, "qx", {
        get: function () {
            return typeGetValue(this.c(TRIXIndicator.qy));
        },
        set: function (a) {
            this.h(TRIXIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    TRIXIndicator.prototype.qi = function () {
        return this.qx;
    };
    TRIXIndicator.prototype.qr = function (a) {
        this.qx = a;
    };
    TRIXIndicator.$t = markType(TRIXIndicator, 'TRIXIndicator', StrategyBasedIndicator.$);
    TRIXIndicator.qy = StrategyBasedIndicator.qu(15, TRIXIndicator.$);
    return TRIXIndicator;
}(StrategyBasedIndicator));
export { TRIXIndicator };
